Selector
--------

.. warning::
    For this module and script to work properly, redis-server must be installed! It is available for most linux
    distributions, or in conda-forge.

.. automodule:: pytroll_watchers.selector
   :members:
